@@ -2,6 +2,14 @@
 #' @export
 magrittr::`%>%`
 
+#' @importFrom rlang is_na
+#' @export
+rlang::is_na
+
+#' @importFrom rlang are_na
+#' @export
+rlang::are_na
+
 #' Group By Helper
 #'
 #' This is a wrapper to facilitate the `grouped_df` S3 method.
@@ -96,6 +104,20 @@ test_if_dataframe <- function(x){
     }
 }
 
+# are there any columns that contain a shadow column?
+any_shadow <- function(x){
+  any(grepl("_NA$",colnames(x)))
+}
+
+# # test if there are shadow columns?
+test_if_any_shadow <- function(x){
+  # test for dataframe
+  test_if_dataframe(x)
+  if (!any_shadow(x)) {
+    stop("Input must contain a shadow column ending in _NA", call. = FALSE)
+    }
+}
+
 #' Helper function to determine whether there are any missings
 #'
 #' @param x a vector
