@@ -1,10 +1,9 @@
 context("geom_miss_point")
 
 library(ggplot2)
-geom_miss_point_plot <-
-  ggplot(airquality,
-         aes(x = Solar.R,
-             y = Ozone)) +
+geom_miss_point_plot <- ggplot(airquality,
+                               aes(x = Solar.R,
+                                   y = Ozone)) +
   geom_miss_point()
 
 test_that("geom_miss_point works",{
